function C = FilterCoeffs(S,F,l,w)

% Coeffs = FilterCoeffs(Spectrum, Filters, l, width = 1nm)
%
% Spectrum = [N x 1] vector
% Filters  = [M x K] matrix, M = no. filter points, K = no. filters
% l =  wavelength index of starting point of filter pass functions (scalar)
% Width (default = 1nm) is spectral sampling interval.

% Liam Pedersen, NASA A.R.C., August 1998
% version 1.0

N = length(S);
[M,K] = size(F);
if (M+l-1 > N)
   M = N-l+1;
end

T = S(l:(l+M-1))*ones(1,K);
C = sum(T.*F(1:M,:));

if (nargin == 4) 
   C = C ./ w;
end
