function [T, l, m, labels] = OOIS2000_SpectralFeatureTemplates(duh)

% [T, l, m, labels] = OOIS2000_SpectralFeatureTemplates(spectrometer)
%
% returns gaussian templates T to correlate with a spectrum to identify features.
% T = cell array of template vectors, with 1 nm wavelength spacing.
% l = vector of starting wavelengths for each template.
% m = vector of template center wavelengths.
% labels = string of labels for feature templates, space delimited.
%
% Templates are consistent with spectral range of instrument
% Templates do NOT overlap with water absorption features of atmosphere.

% VISIBLE correlation feature templates V1 - V11
labels = 'V1 V2 V3 V4 V5 V6 V7 V8 V9 V10 V11 ';
M = [450 500 550 600 650 700 750 800 850 900 950];
m = M;
W = [50  50  50  50  50  50  50  50  50  50  50];
for i = 1:length(M)
   L = (M(i)-W(i)):(M(i)+W(i));
   Vtmin(i) = min(L);
   VT{i} = feature_template(L, M(i), W(i))';
end

% ice/snow correlation feature templates ICE
labels = [labels 'ICE1 ICE2 '];
M = [765 950];
m = [m M];
W = [15  30];
for i = 1:length(M)
   L = (M(i)-W(i)):(M(i)+W(i));
   ICEtmin(i) = min(L);
   ICET{i} = feature_template(L, M(i), W(i))';
end

T = [VT ICET];  % templates, m is the template centers
l = [Vtmin ICEtmin];

