function SFV = SpectralFeatureVector(spectrum, lambda, Templates, LTmin, R, G, B, l_rgb, lmin, lmax)

% SFV = SpectralFeatureVector(specfile, Lmin, Templates, LTmin, R, G, B, l_rgb)
%
%	SFV = [Spectral correlation features, Red, Green, Intensity]
%
%	INPUTS:
%		spectrum = vector of reflectance values, in ascending wavelength, 1nm spacing.
%		lambda	= corresponding wavelength vector of reflectance spectrum. (1nm spacing).
%
%		Templates = cell array of feature templates (1 nm spacing)
%		LT        = array of starting wavelengths (nm) of feature templates
%
%		R, G, B   = vectors of transmission coefficients of R,G,B filters, 1nm spacing.
%		l_rgb     = corresponding wavelength vector
%
%		lmin, lmax = wavelength range (nm) to work with.

% Dependencies:
%
%	SpecFeatureVector
%			|
%			|------>	SpectralCorrelation
%			|						|----------->	correlation
%			|
%			|------>	FilterCoeffs


% Liam Pedersen, NASA ARC/CMU, August 1998

% get indices of wavelengths limits in spectrum vector

imin = find(lambda == lmin);
imax = find(lambda == lmax);
for i = 1:length(LTmin)
  itmin(i) = find(lambda == LTmin(i));
end
         
% compute spectral template correlations:
SF = SpectralCorrelation(spectrum, Templates, itmin);
   
% compute RGI coefficients   
fmin = find(lambda == l_rgb(1));
MaxIntensity = sum(sum([R G B]));

F = FilterCoeffs(spectrum, [R G B], fmin);
  
Intensity = sum(F);
r = F(1)/Intensity;
g = F(2)/Intensity;
b = F(3)/Intensity;
Intensity = Intensity/MaxIntensity;
   
SFV = [SF r g Intensity];
   
